@@ -10,12 +10,12 @@ more information.
      extra = json.JSONField()
 """
 
+import six
 import datetime
 from decimal import Decimal
 from django.db import models
 from django.conf import settings
 from django.utils import simplejson
-from django.utils.encoding import smart_unicode
 
 
 class JSONEncoder(simplejson.JSONEncoder):
@@ -49,6 +49,7 @@ class JSONDict(dict):
     def __repr__(self):
         return dumps(self)
 
+
 class JSONList(list):
     """
     As above
@@ -57,23 +58,23 @@ class JSONList(list):
         return dumps(self)
 
 
-class JSONField(models.TextField):
+class JSONField(six.with_metaclass(models.SubfieldBase, models.TextField)):
     """JSONField is a generic textfield that neatly serializes/unserializes
     JSON objects seamlessly.  Main thingy must be a dict object."""
 
-    # Used so to_python() is called
-    __metaclass__ = models.SubfieldBase
-
     def __init__(self, *args, **kwargs):
-        if 'default' not in kwargs:
+        default = kwargs.get('default', None)
+        if default is None:
             kwargs['default'] = '{}'
+        elif isinstance(default, (list, dict)):
+            kwargs['default'] = dumps(default)
         models.TextField.__init__(self, *args, **kwargs)
 
     def to_python(self, value):
         """Convert our string value to JSON after we load it from the DB"""
         if value is None or value == '':
             return {}
-        elif isinstance(value, basestring):
+        elif isinstance(value, six.string_types):
             res = loads(value)
             if isinstance(res, dict):
                 return JSONDict(**res)
