@@ -13,14 +13,12 @@ from django.core.management.base import BaseCommand, CommandError
 from optparse import make_option
 from datetime import datetime
 from django.conf import settings
-import os
 import sys
-import time
 
 try:
     from django.contrib.staticfiles.handlers import StaticFilesHandler
     USE_STATICFILES = 'django.contrib.staticfiles' in settings.INSTALLED_APPS
-except ImportError, e:
+except ImportError as e:
     USE_STATICFILES = False
 
 try:
@@ -33,6 +31,7 @@ except NameError:
                 return True
         return False
 
+
 def label(code):
     if isinstance(code, str):
         return ('~', 0, code)    # built-in functions ('~' sorts at the end)
@@ -49,7 +48,7 @@ class KCacheGrind(object):
 
     def output(self, out_file):
         self.out_file = out_file
-        print >> out_file, 'events: Ticks'
+        self.out_file.write('events: Ticks\n')
         self._print_summary()
         for entry in self.data:
             self._entry(entry)
@@ -59,7 +58,7 @@ class KCacheGrind(object):
         for entry in self.data:
             totaltime = int(entry.totaltime * 1000)
             max_cost = max(max_cost, totaltime)
-        print >> self.out_file, 'summary: %d' % (max_cost,)
+        self.out_file.write('summary: %d\n' % (max_cost,))
 
     def _entry(self, entry):
         out_file = self.out_file
@@ -67,16 +66,16 @@ class KCacheGrind(object):
         code = entry.code
         #print >> out_file, 'ob=%s' % (code.co_filename,)
         if isinstance(code, str):
-            print >> out_file, 'fi=~'
+            out_file.write('fi=~\n')
         else:
-            print >> out_file, 'fi=%s' % (code.co_filename,)
-        print >> out_file, 'fn=%s' % (label(code),)
+            out_file.write('fi=%s\n' % (code.co_filename,))
+        out_file.write('fn=%s\n' % (label(code),))
 
         inlinetime = int(entry.inlinetime * 1000)
         if isinstance(code, str):
-            print >> out_file, '0 ', inlinetime
+            out_file.write('0  %s\n' % inlinetime)
         else:
-            print >> out_file, '%d %d' % (code.co_firstlineno, inlinetime)
+            out_file.write('%d %d\n' % (code.co_firstlineno, inlinetime))
 
         # recursive calls are counted in entry.calls
         if entry.calls:
@@ -91,46 +90,47 @@ class KCacheGrind(object):
 
         for subentry in calls:
             self._subentry(lineno, subentry)
-        print >> out_file
+        out_file.write("\n")
 
     def _subentry(self, lineno, subentry):
         out_file = self.out_file
         code = subentry.code
-        #print >> out_file, 'cob=%s' % (code.co_filename,)
-        print >> out_file, 'cfn=%s' % (label(code),)
+        #out_file.write('cob=%s\n' % (code.co_filename,))
+        out_file.write('cfn=%s\n' % (label(code),))
         if isinstance(code, str):
-            print >> out_file, 'cfi=~'
-            print >> out_file, 'calls=%d 0' % (subentry.callcount,)
+            out_file.write('cfi=~\n')
+            out_file.write('calls=%d 0\n' % (subentry.callcount,))
         else:
-            print >> out_file, 'cfi=%s' % (code.co_filename,)
-            print >> out_file, 'calls=%d %d' % (
-                subentry.callcount, code.co_firstlineno)
+            out_file.write('cfi=%s\n' % (code.co_filename,))
+            out_file.write('calls=%d %d\n' % (subentry.callcount, code.co_firstlineno))
 
         totaltime = int(subentry.totaltime * 1000)
-        print >> out_file, '%d %d' % (lineno, totaltime)
+        out_file.write('%d %d\n' % (lineno, totaltime))
 
 
 class Command(BaseCommand):
     option_list = BaseCommand.option_list + (
         make_option('--noreload', action='store_false', dest='use_reloader', default=True,
-            help='Tells Django to NOT use the auto-reloader.'),
+                    help='Tells Django to NOT use the auto-reloader.'),
         make_option('--adminmedia', dest='admin_media_path', default='',
-            help='Specifies the directory from which to serve admin media.'),
+                    help='Specifies the directory from which to serve admin media.'),
         make_option('--prof-path', dest='prof_path', default='/tmp',
-            help='Specifies the directory which to save profile information in.'),
+                    help='Specifies the directory which to save profile information in.'),
+        make_option('--prof-file', dest='prof_file', default='{path}.{duration:06d}ms.{time}',
+                    help='Set filename format, default if "{path}.{duration:06d}ms.{time}".'),
         make_option('--nomedia', action='store_true', dest='no_media', default=False,
-            help='Do not profile MEDIA_URL and ADMIN_MEDIA_URL'),
+                    help='Do not profile MEDIA_URL and ADMIN_MEDIA_URL'),
         make_option('--use-cprofile', action='store_true', dest='use_cprofile', default=False,
-            help='Use cProfile if available, this is disabled per default because of incompatibilities.'),
+                    help='Use cProfile if available, this is disabled per default because of incompatibilities.'),
         make_option('--kcachegrind', action='store_true', dest='use_lsprof', default=False,
-            help='Create kcachegrind compatible lsprof files, this requires and automatically enables cProfile.'),
+                    help='Create kcachegrind compatible lsprof files, this requires and automatically enables cProfile.'),
     )
     if USE_STATICFILES:
         option_list += (
             make_option('--nostatic', action="store_false", dest='use_static_handler', default=True,
-                help='Tells Django to NOT automatically serve static files at STATIC_URL.'),
+                        help='Tells Django to NOT automatically serve static files at STATIC_URL.'),
             make_option('--insecure', action="store_true", dest='insecure_serving', default=False,
-                help='Allows serving static files even if DEBUG is False.'),
+                        help='Allows serving static files even if DEBUG is False.'),
         )
     help = "Starts a lightweight Web server with profiling enabled."
     args = '[optional port number, or ipaddr:port]'
@@ -182,11 +182,17 @@ class Command(BaseCommand):
                     import cProfile
                     USE_CPROFILE = True
                 except ImportError:
-                    print "cProfile disabled, module cannot be imported!"
+                    print("cProfile disabled, module cannot be imported!")
                     USE_CPROFILE = False
             if USE_LSPROF and not USE_CPROFILE:
                 raise SystemExit("Kcachegrind compatible output format required cProfile from Python 2.5")
             prof_path = options.get('prof_path', '/tmp')
+
+            prof_file = options.get('prof_file', '{path}.{duration:06d}ms.{time}')
+            if not prof_file.format(path='1', duration=2, time=3):
+                prof_file = '{path}.{duration:06d}ms.{time}'
+                print("Filename format is wrong. Default format used: '{path}.{duration:06d}ms.{time}'.")
+
             def get_exclude_paths():
                 exclude_paths = []
                 media_url = getattr(settings, 'MEDIA_URL', None)
@@ -223,21 +229,21 @@ class Command(BaseCommand):
                         elapms = elap.seconds * 1000.0 + elap.microseconds / 1000.0
                         if USE_LSPROF:
                             kg = KCacheGrind(prof)
-                            kg.output(file(profname, 'w'))
+                            kg.output(open(profname, 'w'))
                         elif USE_CPROFILE:
                             prof.dump_stats(profname)
-                        profname2 = "%s.%06dms.%d.prof" % (path_name, elapms, time.time())
-                        profname2 = os.path.join(prof_path, profname2)
+                        profname2 = prof_file.format(path=path_name, duration=int(elapms), time=int(time.time()))
+                        profname2 = os.path.join(prof_path, "%s.prof" % profname2)
                         if not USE_CPROFILE:
                             prof.close()
                         os.rename(profname, profname2)
                 return handler
 
-            print "Validating models..."
+            print("Validating models...")
             self.validate(display_num_errors=True)
-            print "\nDjango version %s, using settings %r" % (django.get_version(), settings.SETTINGS_MODULE)
-            print "Development server is running at http://%s:%s/" % (addr, port)
-            print "Quit the server with %s." % quit_command
+            print("\nDjango version %s, using settings %r" % (django.get_version(), settings.SETTINGS_MODULE))
+            print("Development server is running at http://%s:%s/" % (addr, port))
+            print("Quit the server with %s." % quit_command)
             path = options.get('admin_media_path', '')
             if not path:
                 admin_media_path = os.path.join(django.__path__[0], 'contrib/admin/static/admin')
@@ -252,12 +258,11 @@ class Command(BaseCommand):
                 if USE_STATICFILES:
                     use_static_handler = options.get('use_static_handler', True)
                     insecure_serving = options.get('insecure_serving', False)
-                    if (use_static_handler and
-                        (settings.DEBUG or insecure_serving)):
+                    if (use_static_handler and (settings.DEBUG or insecure_serving)):
                         handler = StaticFilesHandler(handler)
                 handler = make_profiler_handler(handler)
                 run(addr, int(port), handler)
-            except WSGIServerException, e:
+            except WSGIServerException as e:
                 # Use helpful error messages instead of ugly tracebacks.
                 ERRORS = {
                     13: "You don't have permission to access that port.",
@@ -273,11 +278,10 @@ class Command(BaseCommand):
                 os._exit(1)
             except KeyboardInterrupt:
                 if shutdown_message:
-                    print shutdown_message
+                    print(shutdown_message)
                 sys.exit(0)
         if use_reloader:
             from django.utils import autoreload
             autoreload.main(inner_run)
         else:
             inner_run()
-
